# frozen_string_literal: true

module Pier
  module PageRequest
    class Logger
      def initialize(client:, namespace:)
        @client = client
        @namespace = namespace
      end

      def call(name, started, finished, unique_id, payload)
        log_message = {
          application: namespace,
          request_id: unique_id,
          path: payload[:path],
          format: payload[:format],
          controller: payload[:controller],
          action: payload[:action],
          timestamp: Time.now.utc.iso8601(6),
          view_runtime: payload[:view_runtime],
          db_runtime: payload[:db_runtime],
          status: payload[:status],
        }
        ActiveSupport::Logger.new(STDOUT).info(log_message.to_json)
      end

      private

      attr_reader :client, :namespace, :application

      def tags(payload:)
        %W[
          controller:#{payload[:controller]}
          action:#{payload[:action]}
          format:#{payload[:format]}
          method:#{payload[:method]}
          path:#{payload[:path]}
          status:#{payload[:status]}
          view_runtime:#{payload[:view_runtime]}
          db_runtime:#{payload[:db_runtime]}
        ]
      end
    end
  end
end
