# frozen_string_literal: true
require 'datadog/statsd'

module Pier
  module PageRequest
    class Metric
      def initialize(client:, namespace:)
        @client = client
        @namespace = namespace
      end

      def call(name, started, finished, unique_id, payload)
        client.increment(
          "#{namespace}.http",
          tags: tags(payload: payload)
        )
        client.histogram(
          "#{namespace}.http.response_time",
          payload[:view_runtime].to_f + payload[:db_runtime].to_f,
          tags: tags(payload: payload)
        )

        if payload[:view_runtime]
          client.histogram(
            "#{namespace}.http.response_time.views",
            payload[:view_runtime].to_f,
            tags: tags(payload: payload)
          )
        end

        if payload[:db_runtime]
          client.histogram(
            "#{namespace}.http.response_time.db",
            payload[:db_runtime].to_f,
            tags: tags(payload: payload)
          )
        end
      end

      private

      attr_reader :client, :namespace

      def tags(payload:)
        %W[
          controller:#{payload[:controller]}
          action:#{payload[:action]}
          format:#{payload[:format]}
          method:#{payload[:method]}
          path:#{payload[:path]}
          status:#{payload[:status]}
          view_runtime:#{payload[:view_runtime]}
          db_runtime:#{payload[:db_runtime]}
        ]
      end
    end
  end
end
